initialise method

  1. @override
void initialise(
  1. DogEngine engine
)

Initialises the operation mode with the given engine. This allows for the operation mode to possibly precache some data that would need to be lookup on every invocation otherwise.

Implementation

@override
void initialise(DogEngine engine) {}