FirebaseTimestampConverter class
Properties
-
deriveFuture
→ Type
-
no setterinherited
-
deriveFutureOr
→ Type
-
no setterinherited
-
deriveIterable
→ Type
-
no setterinherited
-
deriveList
→ Type
-
no setterinherited
-
deriveSet
→ Type
-
no setterinherited
-
deriveStream
→ Type
-
no setterinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
isAssociated
→ bool
-
If the converter is associated with the type
T.
Used by the DogEngine.registerAutomatic to determine if a converter
should be automatically registered to T.
finalinherited
-
isNullable
→ bool
-
no setterinherited
-
keepIterables
→ bool
-
If the converter should keep iterables as iterables or convert them
automatically if they occur inside a
DogStructure.
finalinherited
-
modes
→ Map<Type, OperationMode<Timestamp> Function()>
-
Returns a map of
Types to OperationMode factories.
no setter
-
nullable
→ TypeCapture
-
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
struct
→ DogStructure<Timestamp>?
-
The
DogStructure associated with this converter and the type T.
finalinherited
-
typeArgument
→ Type
-
no setterinherited
Methods
-
castIterable(Iterable<Timestamp> iterable)
→ Iterable<Timestamp>
-
inherited
-
castList(List list)
→ List<Timestamp>
-
inherited
-
castSet(Set set)
→ Set<Timestamp>
-
inherited
-
consumeType<RETURN>(RETURN func<_>())
→ RETURN
-
inherited
-
consumeTypeArg<RETURN, ARG>(RETURN func<_>(ARG), ARG arg)
→ RETURN
-
inherited
-
describeOutput(DogEngine engine, SchemaConfig config)
→ SchemaType
-
Generates a
SchemaType describing the output generated by this converter.
inherited
-
isAssignable(dynamic object)
→ bool
-
inherited
-
link(DogEngine engine, bool emitChanges)
→ void
-
Links this instance to the given
engine.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
resolveOperationMode(DogEngine engine, Type opmodeType)
→ OperationMode<Timestamp>?
-
Returns the operation mode for the given
opmodeType or null if the
converter does not support the given operation mode by default.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited