isAssociated property

bool isAssociated
finalinherited

If the converter is associated with the type T. Used by the DogEngine.registerAutomatic to determine if a converter should be automatically registered to T.

Implementation

final bool isAssociated;