struct property
DogStructure<Timestamp> ?
struct
finalinherited
The DogStructure associated with this converter and the type T.
Implementation
final DogStructure<T>? struct;
The DogStructure associated with this converter and the type T.
final DogStructure<T>? struct;