delete method
Deletes the document from Firestore. If the document does not exist, this method does nothing.
Implementation
Future delete() async {
var documentReference = selfCollection.doc(id);
await documentReference.delete();
}
Deletes the document from Firestore. If the document does not exist, this method does nothing.
Future delete() async {
var documentReference = selfCollection.doc(id);
await documentReference.delete();
}