id property
This is the Firestore ID of the document. Will be automatically set when storing a new document, but can also be set manually.
Implementation
String? id;
This is the Firestore ID of the document. Will be automatically set when storing a new document, but can also be set manually.
String? id;