isValid property
Returns true if this object is valid. Does not throw any exceptions if the object is invalid.
Implementation
bool get isValid => DogEngine.instance.validateObject(this, T);
Returns true if this object is valid. Does not throw any exceptions if the object is invalid.
bool get isValid => DogEngine.instance.validateObject(this, T);